@@ -3,9 +3,10 @@ package isolation
 import (
 	"encoding/json"
 	"fmt"
-	"os"
 	"os/exec"
-	"path/filepath"
+	"strconv"
+
+	virt_chroot "kubevirt.io/kubevirt/pkg/virt-handler/virt-chroot"
 
 	containerdisk "kubevirt.io/kubevirt/pkg/container-disk"
 )
@@ -16,8 +17,8 @@ const (
 
 func GetImageInfo(imagePath string, context IsolationResult) (*containerdisk.DiskInfo, error) {
 	// #nosec g204 no risk to use MountNamespace()  argument as it returns a fixed string of "/proc/<pid>/ns/mnt"
-	out, err := exec.Command(
-		"/usr/bin/virt-chroot", "--user", "qemu", "--memory", "1200", "--cpu", "10", "--mount", context.MountNamespace(), "exec", "--",
+	out, err := virt_chroot.ExecChroot(
+		"--user", "qemu", "--memory", "1200", "--cpu", "10", "--mount", context.MountNamespace(), "exec", "--",
 		QEMUIMGPath, "info", imagePath, "--output", "json",
 	).Output()
 	if err != nil {
@@ -37,11 +38,14 @@ func GetImageInfo(imagePath string, context IsolationResult) (*containerdisk.Dis
 	return info, err
 }
 
-func GetFileSize(imagePath string, context IsolationResult) (int64, error) {
-	path := filepath.Join(context.MountRoot(), imagePath)
-	info, err := os.Stat(path)
-	if err != nil {
-		return -1, err
+func GetFileSize(imagePath string, context IsolationResult) (int, error) {
+	// #nosec g204 no risk to use MountNamespace()  argument as it returns a fixed string of "/proc/<pid>/ns/mnt"
+	out, err := virt_chroot.ExecChroot(
+		"--user", "qemu", "--memory", "1200", "--cpu", "10", "--mount", context.MountNamespace(), "exec", "--",
+		"/usr/bin/stat", "--printf=%s", imagePath,
+	).Output()
+	if err == nil {
+		return strconv.Atoi(string(out))
 	}
-	return info.Size(), nil
+	return -1, err
 }
